@@ -28,7 +28,10 @@
 #' `dataset2` is not a Crunch dataset, it will be uploaded as a new
 #' dataset before appending. If it is a CrunchDataset, it may be subsetted with
 #' a filter expression on the rows and a selection of variables on the columns.
-#' @param autorollback Deprecated. This option no longer does anything.
+#' @param upsert Logical: should the append instead "update" rows based on the
+#' primary key variable and "insert" (append) where the primary key values are
+#' new? Default is `FALSE`. Note that this upserting behavior requires a primary
+#' key variable to have been set previously; see [pk()].
 #' @return `dataset1`, updated with `dataset2`, potentially filtered on rows and
 #' variables, appended to it.
 #' @examples
@@ -38,16 +41,9 @@
 #' ds <- appendDataset(ds, new_wave)
 #' }
 #' @export
-appendDataset <- function(dataset1, dataset2, autorollback) {
+appendDataset <- function(dataset1, dataset2, upsert = FALSE) {
     stopifnot(is.dataset(dataset1))
 
-    if (!missing(autorollback)) {
-        warning("The ", sQuote("autorollback"),
-            " argument is deprecated and has no effect",
-            call. = FALSE
-        )
-    }
-
     if (!is.dataset(dataset2)) {
         temp.ds.name <- paste("Appending to", name(dataset1), now())
         message("Creating ", dQuote(temp.ds.name), " as temporary dataset")
@@ -69,7 +65,9 @@ appendDataset <- function(dataset1, dataset2, autorollback) {
 
     ## Preventatively, delete the primary key on dataset1 so that this appends
     ## and not "upsert"
-    pk(dataset1) <- NULL
+    if (!upsert) {
+        pk(dataset1) <- NULL
+    }
 
     ## POST the batch. This will error with a useful message if it fails
     dataset1 <- addBatch(dataset1, body = payload)
