@@ -339,7 +339,7 @@ makeTransFuncs <- function(cat_insert_map, cats_in_array, var_cats) {
             positive_ids <- which(ids(var_cats) %in% positive)
             which.positive <- names(var_cats[positive_ids])
 
-            negative <- unlist(kwarguments(element, var_cats)$negative) #nolint
+            negative <- unlist(subtotalTerms(element, var_cats)$negative) #nolint
             negative_ids <- which(ids(var_cats) %in% negative)
             which.negative <- names(var_cats[negative_ids])
 
@@ -650,9 +650,13 @@ setMethod("transforms<-", c("CrunchCube", "TransformsList"), function(x, value)
     vars <- variables(x)
     # replace the transforms for each dimension
     dims <- CubeDims(mapply(function(dim, val, var) {
-        cats <- categories(var)
+        if (!is.MR(var)) {
+            var_items <- categories(var)
+        } else {
+            var_items <- subvariables(var)
+        }
         val$insertions <- Insertions(
-            data = lapply(val$insertions, makeInsertion, var_categories = cats)
+            data = lapply(val$insertions, makeInsertion, var_items = var_items, alias = alias(var))
         )
         dim$references$view$transform <- jsonprep(val)
         return(dim)
