@@ -6,13 +6,15 @@
 #' @param progress_url A Crunch progress URL
 #' @param wait Number of seconds to wait between polling. This time is increased
 #' 20 percent on each poll.
+#' @param error_handler An optional function that takes the status object
+#' when the progress is less than 0 (meaning the request failed)
 #' @return The percent completed of the progress. Assuming the
 #' `options(crunch.timeout)` (default: 15 minutes) hasn't been reached, this
 #' will be 100. If the timeout is reached, it will be the last reported progress
 #' value.
 #' @export
 #' @importFrom httpcache uncached
-pollProgress <- function(progress_url, wait = .5) {
+pollProgress <- function(progress_url, wait = .5, error_handler = NULL) {
     ## Configure polling interval. Will increase by rate (>1) until reaches max
     max.wait <- 30
     increase.by <- 1.2
@@ -37,7 +39,9 @@ pollProgress <- function(progress_url, wait = .5) {
     }
     close(pb)
 
-    if (status < 0) {
+    if (status < 0 && !is.null(error_handler)) {
+        return(error_handler(prog))
+    } else if (status < 0) {
         email <- "There was an error on the server. Please contact support@crunch.io"
         msg <- prog$message %||% email
         halt(msg)
