@@ -1,7 +1,7 @@
 context("Expression validation")
 
 with_mock_crunch({
-    ds <- loadDataset("test ds")
+    ds <- cachedLoadDataset("test ds")
     badexpr <- ds$NOTAVARIABLE == 3
     age <- 2016 - ds$birthyr
 
